@@ -558,21 +558,18 @@ class Job:
             bool: returns True if paying to ethereum addresses and oracles succeeds.
 
         """
+        eth_addrs = [eth_addr for eth_addr, amount in payouts]
+        hmt_amounts = [int(amount * 10**18) for eth_addr, amount in payouts]
+
+        txn_func = self.job_contract.functions.bulkPayOut
+        txn_info = {
+            "gas_payer": self.gas_payer,
+            "gas_payer_priv": self.gas_payer_priv,
+            "gas": gas
+        }
         try:
             (hash_, url) = upload(results, pub_key)
-            eth_addrs = [eth_addr for eth_addr, amount in payouts]
-            hmt_amounts = [
-                int(amount * 10**18) for eth_addr, amount in payouts
-            ]
-
-            txn_func = self.job_contract.functions.bulkPayOut
             func_args = [eth_addrs, hmt_amounts, url, hash_, 1]
-            txn_info = {
-                "gas_payer": self.gas_payer,
-                "gas_payer_priv": self.gas_payer_priv,
-                "gas": gas
-            }
-
             handle_transaction(txn_func, *func_args, **txn_info)
             return self._bulk_paid() == True
         except Exception as e:
@@ -589,7 +586,9 @@ class Job:
                 "gas": gas
             }
             try:
-                handle_transaction(txn_func, *[], **txn_info)
+                (hash_, url) = upload(results, pub_key)
+                func_args = [eth_addrs, hmt_amounts, url, hash_, 1]
+                handle_transaction(txn_func, *func_args, **txn_info)
                 self.gas_payer = gas_payer
                 self.gas_payer_priv = gas_payer_priv
                 bulk_paid = True
@@ -784,16 +783,15 @@ class Job:
             returns True if contract's state is updated and IPFS upload succeeds.
 
         """
+        txn_func = self.job_contract.functions.storeResults
+        txn_info = {
+            "gas_payer": self.gas_payer,
+            "gas_payer_priv": self.gas_payer_priv,
+            "gas": gas
+        }
         try:
             (hash_, url) = upload(results, pub_key)
-            txn_func = self.job_contract.functions.storeResults
             func_args = [url, hash_]
-            txn_info = {
-                "gas_payer": self.gas_payer,
-                "gas_payer_priv": self.gas_payer_priv,
-                "gas": gas
-            }
-
             handle_transaction(txn_func, *func_args, **txn_info)
             return True
         except Exception as e:
@@ -810,7 +808,9 @@ class Job:
                 "gas": gas
             }
             try:
-                handle_transaction(txn_func, *[], **txn_info)
+                (hash_, url) = upload(results, pub_key)
+                func_args = [url, hash_]
+                handle_transaction(txn_func, *func_args, **txn_info)
                 self.gas_payer = gas_payer
                 self.gas_payer_priv = gas_payer_priv
                 results_stored = True
